@@ -799,7 +799,9 @@ int check_ip_dot(char *ip)
 static int parse_ip(vps_param *vps_p, char *val, int id)
 {
 	char *token;
+	char dst[64];
 	unsigned int ip[16];
+	int family;
 	net_param *net;
 
 	if (id == PARAM_IP_ADD)
@@ -826,10 +828,12 @@ static int parse_ip(vps_param *vps_p, char *val, int id)
 			if (check_ip_dot(token))
 				return ERR_INVAL;
 		}
-		if (get_netaddr(token, ip) < 0)
+		if ((family = get_netaddr(token, ip)) < 0)
 			return ERR_INVAL;
-		if (!find_ip(&net->ip, token)) 
-			add_str_param(&net->ip, token);
+		if (inet_ntop(family, ip, dst, sizeof(dst)) == NULL)
+			return ERR_INVAL;
+		if (!find_ip(&net->ip, dst)) 
+			add_str_param(&net->ip, dst);
 	} while ((token = strtok(NULL, " ")));
 
 	return 0;
@@ -1153,7 +1157,7 @@ static int parse_devnodes_str(const char *str, dev_res *dev)
 	memset(dev, 0, sizeof(*dev));
 	snprintf(dev->name, len, "%s", str);
 	snprintf(buf, sizeof(buf), "/dev/%s", dev->name);
-	if (lstat(buf, &st)) {
+	if (stat(buf, &st)) {
 		logger(-1, errno, "Incorrect device name %s", buf);
 		return ERR_INVAL;
 	}
@@ -1758,7 +1762,6 @@ static int store_name(vps_param *old_p, vps_param *vps_p, vps_config *conf,
 		break;
 	case PARAM_NAME:
 		conf_store_str(conf_h, conf->name, vps_p->res.name.name);
-		add_str_param(conf_h, buf);
 		break;
 	}
 	return 0;
@@ -1888,6 +1891,7 @@ static int parse(envid_t veid, vps_param *vps_p, char *val, int id)
 		break;
 	case PARAM_IPV6NET:
 		ret = conf_parse_yesno(&vps_p->res.net.ipv6_net, val, 1);
+		vps_p->del_res.net.ipv6_net = vps_p->res.net.ipv6_net;
 		break;
 	case PARAM_NETDEV_ADD:
 		ret = add_netdev(&vps_p->res.net, val);
@@ -2752,5 +2756,6 @@ int merge_global_param(vps_param *dst, vps_param *src)
 {
 	MERGE_INT(res.dq.enable);
 	MERGE_INT(res.net.ipv6_net);
+	MERGE_INT(del_res.net.ipv6_net);
 	return 0;
 }
